@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Class::Rule;
 # ABSTRACT: File finder using Path::Class
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 # Register warnings category
 use warnings::register;
@@ -104,9 +104,9 @@ sub iter {
           # for postorder, requeue as reference to signal it can be returned
           # without being retested
           push @next, { path => \$item, depth => $depth}
-            if $opts->{depthfirst} < 0;
+            if $interest && $opts->{depthfirst} > 0;
           unshift @queue, @next;
-          redo LOOP if $opts->{depthfirst} < 0;
+          redo LOOP if $opts->{depthfirst} > 0;
         }
         else {
           push @queue, $self->_taskify($depth+1, $item->children);
@@ -477,7 +477,7 @@ Path::Class::Rule - File finder using Path::Class
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -1002,7 +1002,7 @@ considerations.  See L<perlport> for details.
 =head1 SEE ALSO
 
 There are many other file finding modules out there.  They all have various
-features/deficiencies, depending on one's preferences and needs.  Here is an
+features/deficiencies, depending on your preferences and needs.  Here is an
 (incomplete) list of alternatives, with some comparison commentary.
 
 L<File::Find> is part of the Perl core.  It requires the user to write a
@@ -1022,7 +1022,7 @@ L<File::Next> provides iterators for file, directories or "everything".  It
 takes two callbacks, one to match files and one to decide which directories to
 descend.  It does not allow control over breadth/depth order, though it does
 provide means to sort files for processing within a directory. Like
-L<File::Find>, it requires callbacks to use global varaibles.
+L<File::Find>, it requires callbacks to use global variables.
 
 L<Path::Class::Iterator> walks a directory structure with an iterator.  It is
 implemented as L<Path::Class> subclasses, which adds a degree of extra
@@ -1032,13 +1032,13 @@ L<Path::Class::Iterator::Dir> object for evaluation.
 
 L<File::Find::Object> and companion L<File::Find::Object::Rule> are like
 File::Find and File::Find::Rule, but without File::Find inside.  They use an
-interator that does not precompute results. They can return
+iterator that does not precompute results. They can return
 L<File::Find::Object::Result> objects, which give a subset of the utility
 of Path::Class objects.  L<File::Find::Object::Rule> appears to be a literal
 translation of L<File::Find::Rule>, including oddities like making C<-M> into a
 boolean.
 
-L<File::chdir::WalkDir> recursively chdirs a tree, calling a callback on each
+L<File::chdir::WalkDir> recursively descends a tree, calling a callback on each
 file.  No iterator.  Supports exclusion patterns.  Depth-first post-order by
 default, but offers pre-order option. Does not process symlinks.
 
@@ -1059,15 +1059,15 @@ each file (or directory) in the set.  There is no iterator.  There is no
 control over ordering.  Symlinks are not followed.  It has several extra
 features for checksumming the set and creating tarballs with F</bin/tar>.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
 =head2 Bugs / Feature Requests
 
-Please report any bugs or feature requests by email to C<bug-path-class-rule at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Path-Class-Rule>. You will be automatically notified of any
-progress on the request by the system.
+Please report any bugs or feature requests through the issue tracker
+at L<http://rt.cpan.org/Public/Dist/Display.html?Name=Path-Class-Rule>.
+You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
 
